@@ -5,10 +5,10 @@
 # Compare files created by /usr/src/etc/Makefile (or the directory
 # the user specifies) with the currently installed copies.
 
-# Copyright 1998-2001 Douglas Barton
+# Copyright 1998-2002 Douglas Barton
 # DougB@FreeBSD.org
 
-# $FreeBSD: src/usr.sbin/mergemaster/mergemaster.sh,v 1.25 2001/08/07 06:22:12 dougb Exp $
+# $FreeBSD: src/usr.sbin/mergemaster/mergemaster.sh,v 1.26 2002/02/12 09:54:56 dougb Exp $
 
 PATH=/bin:/usr/bin:/usr/sbin
 
@@ -109,6 +109,9 @@ diff_loop () {
     "${HANDLE_COMPFILE}" = "NOT V" ]; do
     if [ -f "${DESTDIR}${COMPFILE#.}" -a -f "${COMPFILE}" ]; then
       if [ "${HANDLE_COMPFILE}" = "v" -o "${HANDLE_COMPFILE}" = "V" ]; then
+	echo ''
+	echo '   ======================================================================   '
+	echo ''
         (
           echo ''
           echo "  *** Displaying differences between ${COMPFILE} and installed version:"
@@ -731,7 +734,7 @@ for COMPFILE in `find . -type f -size +0`; do
     # user will have less to wade through if files are left to merge by hand.
     #
     CVSID1=`grep "[$]${CVS_ID_TAG}:" ${DESTDIR}${COMPFILE#.} 2>/dev/null`
-    CVSID2=`grep "[$]${CVS_ID_TAG}:" ${COMPFILE} 2>/dev/null`
+    CVSID2=`grep "[$]${CVS_ID_TAG}:" ${COMPFILE} 2>/dev/null` || CVSID2=none
 
     case "${CVSID2}" in
     "${CVSID1}")
